/**
 *******************************************************************************
 * @file    main.c
 *
 * @brief   Main program body.
 *
 * @author  DPM
 *
 * @version V1.0.0
 *
 * @date    2024-5-6
 *
 *******************************************************************************/

/*
    Copyright (c) 2024, DP Microelectronics Inc.

    Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice, this
       list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
    3. Neither the name of the copyright holder nor the names of its contributors
       may be used to endorse or promote products derived from this software without
       specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

/* Files include */
#include "main.h"
#include "dpm32m0xx.h"
#include "dpm32m0xx_eval.h"
#include "systick.h"
#include <stdio.h>

/**
  * @addtogroup DPM32M08X_LibSamples
  * @{
  */

/**
  * @addtogroup GPIO
  * @{
  */

/**
  * @addtogroup GPIO_KeyPollingMode
  * @{
  */

/* Private typedef --------------------------------------------------------------*/

/* Private define ---------------------------------------------------------------*/

/* Private macro ----------------------------------------------------------------*/

/* Private variables ------------------------------------------------------------*/

/* Private functions ------------------------------------------------------------*/

/**
  * @brief  The program entry function.
  * @retval int
  */
int main(void)
{
  /* Configure the system clock */
  SystemClockInit();

  /* Configure the system tick */
  SystickInit();

  /* Led Init */
  EVAL_LedInit(LED1);
  EVAL_LedInit(LED2);
  EVAL_LedInit(LED3);
  EVAL_LedInit(LED4);

  /* Key Init */
  EVAL_KeyInit(KEY_UP, KEY_MODE_GPIO);
  EVAL_KeyInit(KEY1, KEY_MODE_GPIO);
  EVAL_KeyInit(KEY2, KEY_MODE_GPIO);
  EVAL_KeyInit(KEY3, KEY_MODE_GPIO);

  while(1)
  {
    /* check whether the button is pressed */
    if(SET == EVAL_KeyStateGet(KEY_UP))
    {
      DelayMs(100);

      /* check whether the button is pressed */
      if(SET == EVAL_KeyStateGet(KEY_UP))
      {
        EVAL_LedToggle(LED1);
      }

      while(SET == EVAL_KeyStateGet(KEY_UP));
    }

    /* check whether the button is pressed */
    if(RESET == EVAL_KeyStateGet(KEY1))
    {
      DelayMs(100);

      /* check whether the button is pressed */
      if(RESET == EVAL_KeyStateGet(KEY1))
      {
        EVAL_LedToggle(LED2);
      }

      while(RESET == EVAL_KeyStateGet(KEY1));
    }

    /* check whether the button is pressed */
    if(RESET == EVAL_KeyStateGet(KEY2))
    {
      DelayMs(100);

      /* check whether the button is pressed */
      if(RESET == EVAL_KeyStateGet(KEY2))
      {
        EVAL_LedToggle(LED3);
      }

      while(RESET == EVAL_KeyStateGet(KEY2));
    }

    /* check whether the button is pressed */
    if(RESET == EVAL_KeyStateGet(KEY3))
    {
      DelayMs(100);

      /* check whether the button is pressed */
      if(RESET == EVAL_KeyStateGet(KEY3))
      {
        EVAL_LedToggle(LED4);
      }

      while(RESET == EVAL_KeyStateGet(KEY3));
    }
  }
}





/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) COPYRIGHT DP *****END OF FILE ***************************/
